==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateEnteringEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateEnteringEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
            }
            if (a.k(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
            a.ac("ResponsiveStateEnteringEventArgs", () => new ResponsiveStateEnteringEventArgsDescription());
            a.ab("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateEnteringEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateEnteringEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
            }
            if (a.k(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
            a.ae("ResponsiveStateEnteringEventArgs", () => new ResponsiveStateEnteringEventArgsDescription());
            a.ad("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
})();
